[gnome-software/wip/rancell/ubuntu-3-20-rebase: 23/62] Use GFile instead of a filename when converting apps.



commit 7c874260c0978d792869d5c93f16fbb263a22c26
Author: Robert Ancell <robert ancell canonical com>
Date:   Mon Apr 25 11:20:51 2016 +0200

    Use GFile instead of a filename when converting apps.

 src/gs-cmd.c                               |   12 ++++---
 src/gs-plugin-loader-sync.c                |   36 +++++++++---------
 src/gs-plugin-loader-sync.h                |    4 +-
 src/gs-plugin-loader.c                     |   53 ++++++++++++++-------------
 src/gs-plugin-loader.h                     |    6 ++--
 src/gs-plugin.h                            |    8 ++--
 src/gs-shell-details.c                     |   37 ++++++++++---------
 src/gs-shell-extras.c                      |   26 +++++++------
 src/gs-utils.c                             |    4 +--
 src/gs-utils.h                             |    2 +-
 src/plugins/gs-plugin-fwupd.c              |   16 +++++----
 src/plugins/gs-plugin-packagekit-refresh.c |   18 +++++----
 src/plugins/gs-plugin-xdg-app.c            |   16 ++++-----
 13 files changed, 123 insertions(+), 115 deletions(-)
---
diff --git a/src/gs-cmd.c b/src/gs-cmd.c
index 4c61952..f71df42 100644
--- a/src/gs-cmd.c
+++ b/src/gs-cmd.c
@@ -192,6 +192,7 @@ main (int argc, char **argv)
        g_autoptr(GError) error = NULL;
        g_autofree gchar *refine_flags_str = NULL;
        g_autoptr(GsApp) app = NULL;
+       g_autoptr(GFile) file = NULL;
        g_autoptr(GsPluginLoader) plugin_loader = NULL;
        g_autoptr(AsProfile) profile = NULL;
        g_autoptr(AsProfileTask) ptask = NULL;
@@ -314,11 +315,12 @@ main (int argc, char **argv)
                                break;
                }
        } else if (argc == 3 && g_strcmp0 (argv[1], "filename-to-app") == 0) {
-               app = gs_plugin_loader_filename_to_app (plugin_loader,
-                                                       argv[2],
-                                                       refine_flags,
-                                                       NULL,
-                                                       &error);
+               file = g_file_new_for_path (argv[2]);
+               app = gs_plugin_loader_file_to_app (plugin_loader,
+                                                   file,
+                                                   refine_flags,
+                                                   NULL,
+                                                   &error);
                if (app == NULL) {
                        ret = FALSE;
                } else {
diff --git a/src/gs-plugin-loader-sync.c b/src/gs-plugin-loader-sync.c
index e2fed01..db63904 100644
--- a/src/gs-plugin-loader-sync.c
+++ b/src/gs-plugin-loader-sync.c
@@ -615,27 +615,27 @@ gs_plugin_loader_refresh (GsPluginLoader *plugin_loader,
 }
 
 static void
-gs_plugin_loader_filename_to_app_finish_sync (GObject *source_object,
-                                             GAsyncResult *res,
-                                             gpointer user_data)
+gs_plugin_loader_file_to_app_finish_sync (GObject *source_object,
+                                         GAsyncResult *res,
+                                         gpointer user_data)
 {
        GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
        GsPluginLoaderHelper *helper = (GsPluginLoaderHelper *) user_data;
-       helper->app = gs_plugin_loader_filename_to_app_finish (plugin_loader,
-                                                              res,
-                                                              helper->error);
+       helper->app = gs_plugin_loader_file_to_app_finish (plugin_loader,
+                                                          res,
+                                                          helper->error);
        g_main_loop_quit (helper->loop);
 }
 
 /**
- * gs_plugin_loader_filename_to_app:
+ * gs_plugin_loader_file_to_app:
  **/
 GsApp *
-gs_plugin_loader_filename_to_app (GsPluginLoader *plugin_loader,
-                                 const gchar *filename,
-                                 GsPluginRefineFlags flags,
-                                 GCancellable *cancellable,
-                                 GError **error)
+gs_plugin_loader_file_to_app (GsPluginLoader *plugin_loader,
+                             GFile *file,
+                             GsPluginRefineFlags flags,
+                             GCancellable *cancellable,
+                             GError **error)
 {
        GsPluginLoaderHelper helper;
 
@@ -648,12 +648,12 @@ gs_plugin_loader_filename_to_app (GsPluginLoader *plugin_loader,
        g_main_context_push_thread_default (helper.context);
 
        /* run async method */
-       gs_plugin_loader_filename_to_app_async (plugin_loader,
-                                               filename,
-                                               flags,
-                                               cancellable,
-                                               gs_plugin_loader_filename_to_app_finish_sync,
-                                               &helper);
+       gs_plugin_loader_file_to_app_async (plugin_loader,
+                                           file,
+                                           flags,
+                                           cancellable,
+                                           gs_plugin_loader_file_to_app_finish_sync,
+                                           &helper);
        g_main_loop_run (helper.loop);
 
        g_main_context_pop_thread_default (helper.context);
diff --git a/src/gs-plugin-loader-sync.h b/src/gs-plugin-loader-sync.h
index 158c81d..376a1c3 100644
--- a/src/gs-plugin-loader-sync.h
+++ b/src/gs-plugin-loader-sync.h
@@ -86,8 +86,8 @@ GsApp         *gs_plugin_loader_get_app_by_id         (GsPluginLoader *plugin_loader,
                                                         GsPluginRefineFlags flags,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
-GsApp          *gs_plugin_loader_filename_to_app       (GsPluginLoader *plugin_loader,
-                                                        const gchar    *filename,
+GsApp          *gs_plugin_loader_file_to_app           (GsPluginLoader *plugin_loader,
+                                                        GFile          *file,
                                                         GsPluginRefineFlags flags,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
diff --git a/src/gs-plugin-loader.h b/src/gs-plugin-loader.h
index 1a3a3d2..61bc12b 100644
--- a/src/gs-plugin-loader.h
+++ b/src/gs-plugin-loader.h
@@ -171,13 +171,13 @@ void               gs_plugin_loader_search_what_provides_async (GsPluginLoader    
*plugin_loade
 GList          *gs_plugin_loader_search_what_provides_finish (GsPluginLoader   *plugin_loader,
                                                         GAsyncResult   *res,
                                                         GError         **error);
-void            gs_plugin_loader_filename_to_app_async (GsPluginLoader *plugin_loader,
-                                                        const gchar    *filename,
+void            gs_plugin_loader_file_to_app_async     (GsPluginLoader *plugin_loader,
+                                                        GFile          *file,
                                                         GsPluginRefineFlags flags,
                                                         GCancellable   *cancellable,
                                                         GAsyncReadyCallback callback,
                                                         gpointer        user_data);
-GsApp          *gs_plugin_loader_filename_to_app_finish(GsPluginLoader *plugin_loader,
+GsApp          *gs_plugin_loader_file_to_app_finish    (GsPluginLoader *plugin_loader,
                                                         GAsyncResult   *res,
                                                         GError         **error);
 void            gs_plugin_loader_url_to_app_async      (GsPluginLoader *plugin_loader,
diff --git a/src/gs-plugin.h b/src/gs-plugin.h
index b6c18f8..a7a7cc0 100644
--- a/src/gs-plugin.h
+++ b/src/gs-plugin.h
@@ -162,9 +162,9 @@ typedef gboolean     (*GsPluginRefreshFunc  )       (GsPlugin       *plugin,
                                                         GsPluginRefreshFlags flags,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
-typedef gboolean        (*GsPluginFilenameToAppFunc)   (GsPlugin       *plugin,
+typedef gboolean        (*GsPluginFileToAppFunc)       (GsPlugin       *plugin,
                                                         GList          **list,
-                                                        const gchar    *filename,
+                                                        GFile          *file,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
 typedef gboolean        (*GsPluginUrlToAppFunc)        (GsPlugin       *plugin,
@@ -336,9 +336,9 @@ gboolean     gs_plugin_refresh                      (GsPlugin       *plugin,
                                                         GsPluginRefreshFlags flags,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
-gboolean        gs_plugin_filename_to_app              (GsPlugin       *plugin,
+gboolean        gs_plugin_file_to_app                  (GsPlugin       *plugin,
                                                         GList          **list,
-                                                        const gchar    *filename,
+                                                        GFile          *file,
                                                         GCancellable   *cancellable,
                                                         GError         **error);
 gboolean        gs_plugin_url_to_app                   (GsPlugin       *plugin,
diff --git a/src/gs-shell-extras.c b/src/gs-shell-extras.c
index 96ba78d..abcc910 100644
--- a/src/gs-shell-extras.c
+++ b/src/gs-shell-extras.c
@@ -563,9 +563,9 @@ search_files_cb (GObject *source_object,
 }
 
 static void
-filename_to_app_cb (GObject *source_object,
-                    GAsyncResult *res,
-                    gpointer user_data)
+file_to_app_cb (GObject *source_object,
+                GAsyncResult *res,
+                gpointer user_data)
 {
        SearchData *search_data = (SearchData *) user_data;
        GsShellExtras *self = search_data->self;
@@ -573,7 +573,7 @@ filename_to_app_cb (GObject *source_object,
        GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
        g_autoptr(GError) error = NULL;
 
-       app = gs_plugin_loader_filename_to_app_finish (plugin_loader, res, &error);
+       app = gs_plugin_loader_file_to_app_finish (plugin_loader, res, &error);
        if (app == NULL) {
                if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
                        g_debug ("extras: search what provides cancelled");
@@ -702,15 +702,17 @@ gs_shell_extras_load (GsShellExtras *self, GPtrArray *array_search_data)
                                                             search_files_cb,
                                                             search_data);
                } else if (search_data->package_filename != NULL) {
+                       g_autoptr (GFile) file = NULL;
                        g_debug ("resolving filename to app: '%s'", search_data->package_filename);
-                       gs_plugin_loader_filename_to_app_async (self->plugin_loader,
-                                                               search_data->package_filename,
-                                                               GS_PLUGIN_REFINE_FLAGS_DEFAULT |
-                                                               GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
-                                                               GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
-                                                               self->search_cancellable,
-                                                               filename_to_app_cb,
-                                                               search_data);
+                       file = g_file_new_for_path (search_data->package_filename);
+                       gs_plugin_loader_file_to_app_async (self->plugin_loader,
+                                                           file,
+                                                           GS_PLUGIN_REFINE_FLAGS_DEFAULT |
+                                                           GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+                                                           GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
+                                                           self->search_cancellable,
+                                                           file_to_app_cb,
+                                                           search_data);
                } else {
                        g_debug ("searching what provides: '%s'", search_data->search);
                        gs_plugin_loader_search_what_provides_async (self->plugin_loader,
diff --git a/src/gs-utils.c b/src/gs-utils.c
index 7173923..670f896 100644
--- a/src/gs-utils.c
+++ b/src/gs-utils.c
@@ -495,16 +495,14 @@ gs_utils_get_permission (const gchar *id)
  * gs_utils_get_content_type:
  */
 gchar *
-gs_utils_get_content_type (const gchar *filename,
+gs_utils_get_content_type (GFile *file,
                           GCancellable *cancellable,
                           GError **error)
 {
        const gchar *tmp;
-       g_autoptr(GFile) file = NULL;
        g_autoptr(GFileInfo) info = NULL;
 
        /* get content type */
-       file = g_file_new_for_path (filename);
        info = g_file_query_info (file,
                                  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
                                  G_FILE_QUERY_INFO_NONE,
diff --git a/src/gs-utils.h b/src/gs-utils.h
index 0e8aba6..82ef42b 100644
--- a/src/gs-utils.h
+++ b/src/gs-utils.h
@@ -36,7 +36,7 @@ void   gs_container_remove_all        (GtkContainer   *container);
 void    gs_grab_focus_when_mapped      (GtkWidget      *widget);
 
 guint   gs_utils_get_file_age          (GFile          *file);
-gchar  *gs_utils_get_content_type      (const gchar    *filename,
+gchar  *gs_utils_get_content_type      (GFile          *file,
                                         GCancellable   *cancellable,
                                         GError         **error);
 
diff --git a/src/plugins/gs-plugin-fwupd.c b/src/plugins/gs-plugin-fwupd.c
index 104b094..5fceca0 100644
--- a/src/plugins/gs-plugin-fwupd.c
+++ b/src/plugins/gs-plugin-fwupd.c
@@ -1041,14 +1041,14 @@ gs_plugin_app_update (GsPlugin *plugin,
 }
 
 /**
- * gs_plugin_filename_to_app:
+ * gs_plugin_file_to_app:
  */
 gboolean
-gs_plugin_filename_to_app (GsPlugin *plugin,
-                          GList **list,
-                          const gchar *filename,
-                          GCancellable *cancellable,
-                          GError **error)
+gs_plugin_file_to_app (GsPlugin *plugin,
+                      GList **list,
+                      GFile *file,
+                      GCancellable *cancellable,
+                      GError **error)
 {
        FwupdDeviceFlags flags = FU_DEVICE_FLAG_ALLOW_OFFLINE;
        GVariant *body;
@@ -1069,9 +1069,10 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
        const gchar *mimetypes[] = {
                "application/vnd.ms-cab-compressed",
                NULL };
+       g_autofree gchar *filename = NULL;
 
        /* does this match any of the mimetypes we support */
-       content_type = gs_utils_get_content_type (filename, cancellable, error);
+       content_type = gs_utils_get_content_type (file, cancellable, error);
        if (content_type == NULL)
                return FALSE;
        if (!g_strv_contains (mimetypes, content_type))
@@ -1083,6 +1084,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
                return FALSE;
 
        /* open file */
+       filename = g_file_get_path (file);
        fd = open (filename, O_RDONLY);
        if (fd < 0) {
                g_set_error (error,
diff --git a/src/plugins/gs-plugin-packagekit-refresh.c b/src/plugins/gs-plugin-packagekit-refresh.c
index 5d3de2e..9f8f119 100644
--- a/src/plugins/gs-plugin-packagekit-refresh.c
+++ b/src/plugins/gs-plugin-packagekit-refresh.c
@@ -260,14 +260,14 @@ gs_plugin_packagekit_refresh_guess_app_id (GsPlugin *plugin,
 }
 
 /**
- * gs_plugin_filename_to_app:
+ * gs_plugin_file_to_app:
  */
 gboolean
-gs_plugin_filename_to_app (GsPlugin *plugin,
-                          GList **list,
-                          const gchar *filename,
-                          GCancellable *cancellable,
-                          GError **error)
+gs_plugin_file_to_app (GsPlugin *plugin,
+                      GList **list,
+                      GFile *file,
+                      GCancellable *cancellable,
+                      GError **error)
 {
        const gchar *package_id;
        PkDetails *item;
@@ -275,6 +275,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
        g_autoptr (PkResults) results = NULL;
        g_autofree gchar *basename = NULL;
        g_autofree gchar *content_type = NULL;
+       g_autofree gchar *filename = NULL;
        g_autofree gchar *license_spdx = NULL;
        g_auto(GStrv) files = NULL;
        g_auto(GStrv) split = NULL;
@@ -288,7 +289,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
                NULL };
 
        /* does this match any of the mimetypes we support */
-       content_type = gs_utils_get_content_type (filename, cancellable, error);
+       content_type = gs_utils_get_content_type (file, cancellable, error);
        if (content_type == NULL)
                return FALSE;
        if (!g_strv_contains (mimetypes, content_type))
@@ -298,6 +299,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
        data.ptask = NULL;
 
        /* get details */
+       filename = g_file_get_path (file);
        files = g_strsplit (filename, "\t", -1);
        pk_client_set_cache_age (PK_CLIENT (plugin->priv->task), G_MAXUINT);
        results = pk_client_get_details_local (PK_CLIENT (plugin->priv->task),
@@ -354,7 +356,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
        /* look for a desktop file so we can use a valid application id */
        if (!gs_plugin_packagekit_refresh_guess_app_id (plugin,
                                                        app,
-                                                       filename,
+                                                       g_file_get_path (file),
                                                        cancellable,
                                                        error))
                return FALSE;
diff --git a/src/plugins/gs-plugin-xdg-app.c b/src/plugins/gs-plugin-xdg-app.c
index e69ceb2..8d4b6d4 100644
--- a/src/plugins/gs-plugin-xdg-app.c
+++ b/src/plugins/gs-plugin-xdg-app.c
@@ -1401,21 +1401,20 @@ gs_plugin_app_update (GsPlugin *plugin,
 }
 
 /**
- * gs_plugin_filename_to_app:
+ * gs_plugin_file_to_app:
  */
 gboolean
-gs_plugin_filename_to_app (GsPlugin *plugin,
-                          GList **list,
-                          const gchar *filename,
-                          GCancellable *cancellable,
-                          GError **error)
+gs_plugin_file_to_app (GsPlugin *plugin,
+                      GList **list,
+                      GFile *file,
+                      GCancellable *cancellable,
+                      GError **error)
 {
        g_autofree gchar *content_type = NULL;
        g_autofree gchar *id_prefixed = NULL;
        g_autoptr(GBytes) appstream_gz = NULL;
        g_autoptr(GBytes) icon_data = NULL;
        g_autoptr(GBytes) metadata = NULL;
-       g_autoptr(GFile) file = NULL;
        g_autoptr(GsApp) app = NULL;
        g_autoptr(XdgAppBundleRef) xref_bundle = NULL;
        const gchar *mimetypes[] = {
@@ -1423,14 +1422,13 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
                NULL };
 
        /* does this match any of the mimetypes we support */
-       content_type = gs_utils_get_content_type (filename, cancellable, error);
+       content_type = gs_utils_get_content_type (file, cancellable, error);
        if (content_type == NULL)
                return FALSE;
        if (!g_strv_contains (mimetypes, content_type))
                return TRUE;
 
        /* load bundle */
-       file = g_file_new_for_path (filename);
        xref_bundle = xdg_app_bundle_ref_new (file, error);
        if (xref_bundle == NULL) {
                g_prefix_error (error, "error loading bundle: ");


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gs-plugin-loader.c b/src/gs-plugin-loader.c
index 27fdf7e..83064a9 100644
--- a/src/gs-plugin-loader.c
+++ b/src/gs-plugin-loader.c
@@ -71,7 +71,7 @@ typedef struct {
        GList                           *list;
        GsPluginRefineFlags              flags;
        gchar                           *value;
-       gchar                           *filename;
+       GFile                           *file;
        guint                            cache_age;
        GsCategory                      *category;
        GsApp                           *app;
@@ -89,8 +89,9 @@ gs_plugin_loader_free_async_state (GsPluginLoaderAsyncState *state)
                g_object_unref (state->app);
        if (state->review != NULL)
                g_object_unref (state->review);
+       if (state->file != NULL)
+               g_object_unref (state->file);
 
-       g_free (state->filename);
        g_free (state->value);
        gs_plugin_list_free (state->list);
        g_slice_free (GsPluginLoaderAsyncState, state);
@@ -3652,23 +3653,23 @@ gs_plugin_loader_refresh_finish (GsPluginLoader *plugin_loader,
 /******************************************************************************/
 
 /**
- * gs_plugin_loader_filename_to_app_thread_cb:
+ * gs_plugin_loader_file_to_app_thread_cb:
  **/
 static void
-gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
-                                           gpointer object,
-                                           gpointer task_data,
-                                           GCancellable *cancellable)
+gs_plugin_loader_file_to_app_thread_cb (GTask *task,
+                                       gpointer object,
+                                       gpointer task_data,
+                                       GCancellable *cancellable)
 {
        GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (object);
        GsPluginLoaderPrivate *priv = gs_plugin_loader_get_instance_private (plugin_loader);
-       const gchar *function_name = "gs_plugin_filename_to_app";
+       const gchar *function_name = "gs_plugin_file_to_app";
        gboolean ret = TRUE;
        GError *error = NULL;
        GList *l;
        GsPluginLoaderAsyncState *state = (GsPluginLoaderAsyncState *) task_data;
        GsPlugin *plugin;
-       GsPluginFilenameToAppFunc plugin_func = NULL;
+       GsPluginFileToAppFunc plugin_func = NULL;
        guint i;
 
        /* run each plugin */
@@ -3690,7 +3691,7 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
                                          "GsPlugin::%s(%s)",
                                          plugin->name,
                                          function_name);
-               ret = plugin_func (plugin, &state->list, state->filename,
+               ret = plugin_func (plugin, &state->list, state->file,
                                   cancellable, &error_local);
                if (!ret) {
                        g_warning ("failed to call %s on %s: %s",
@@ -3729,7 +3730,7 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
                g_task_return_new_error (task,
                                         GS_PLUGIN_LOADER_ERROR,
                                         GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
-                                        "no filename_to_app results to show");
+                                        "no file_to_app results to show");
                return;
        }
 
@@ -3739,16 +3740,16 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
                                         GS_PLUGIN_LOADER_ERROR,
                                         GS_PLUGIN_LOADER_ERROR_NO_RESULTS,
                                         "no application was created for %s",
-                                        state->filename);
+                                        g_file_get_path (state->file));
                return;
        }
        g_task_return_pointer (task, g_object_ref (state->list->data), (GDestroyNotify) g_object_unref);
 }
 
 /**
- * gs_plugin_loader_filename_to_app_async:
+ * gs_plugin_loader_file_to_app_async:
  *
  * This method calls all plugins that implement the gs_plugin_add_filename_to_app()
  * function. The plugins can either return #GsApp objects of kind
  * %AS_APP_KIND_DESKTOP for bonafide applications, or #GsApp's of kind
  * %AS_APP_KIND_GENERIC for packages that may or may not be applications.
@@ -3761,12 +3762,12 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
  * from the gs_app_get_local_file() method.
  **/
 void
-gs_plugin_loader_filename_to_app_async (GsPluginLoader *plugin_loader,
-                                       const gchar *filename,
-                                       GsPluginRefineFlags flags,
-                                       GCancellable *cancellable,
-                                       GAsyncReadyCallback callback,
-                                       gpointer user_data)
+gs_plugin_loader_file_to_app_async (GsPluginLoader *plugin_loader,
+                                   GFile *file,
+                                   GsPluginRefineFlags flags,
+                                   GCancellable *cancellable,
+                                   GAsyncReadyCallback callback,
+                                   gpointer user_data)
 {
        GsPluginLoaderAsyncState *state;
        g_autoptr(GTask) task = NULL;
@@ -3777,24 +3778,24 @@ gs_plugin_loader_filename_to_app_async (GsPluginLoader *plugin_loader,
        /* save state */
        state = g_slice_new0 (GsPluginLoaderAsyncState);
        state->flags = flags;
-       state->filename = g_strdup (filename);
+       state->file = g_object_ref (file);
 
        /* run in a thread */
        task = g_task_new (plugin_loader, cancellable, callback, user_data);
        g_task_set_task_data (task, state, (GDestroyNotify) gs_plugin_loader_free_async_state);
        g_task_set_return_on_cancel (task, TRUE);
-       g_task_run_in_thread (task, gs_plugin_loader_filename_to_app_thread_cb);
+       g_task_run_in_thread (task, gs_plugin_loader_file_to_app_thread_cb);
 }
 
 /**
- * gs_plugin_loader_filename_to_app_finish:
+ * gs_plugin_loader_file_to_app_finish:
  *
  * Return value: (element-type GsApp) (transfer full): An application, or %NULL
  **/
 GsApp *
-gs_plugin_loader_filename_to_app_finish (GsPluginLoader *plugin_loader,
-                                        GAsyncResult *res,
-                                        GError **error)
+gs_plugin_loader_file_to_app_finish (GsPluginLoader *plugin_loader,
+                                    GAsyncResult *res,
+                                    GError **error)
 {
        g_return_val_if_fail (GS_IS_PLUGIN_LOADER (plugin_loader), NULL);
        g_return_val_if_fail (G_IS_TASK (res), NULL);
@@ -3739,16 +3740,16 @@ gs_plugin_loader_filename_to_app_thread_cb (GTask *task,
  *
- * This method calls all plugins that implement the gs_plugin_add_filename_to_app()
+ * This method calls all plugins that implement the gs_plugin_add_file_to_app()
  * function. The plugins can either return #GsApp objects of kind
  * %AS_APP_KIND_DESKTOP for bonafide applications, or #GsApp's of kind
diff --git a/src/gs-shell-details.c b/src/gs-shell-details.c
index 3a588f8..59935aa 100644
--- a/src/gs-shell-details.c
+++ b/src/gs-shell-details.c
@@ -173,7 +173,7 @@ gs_shell_details_switch_to (GsPage *page, gboolean scroll_up)
        widget = GTK_WIDGET (gtk_builder_get_object (self->builder, "application_details_header"));
        gtk_widget_show (widget);
 
        /* not set, perhaps filename-to-app */
        if (self->app == NULL)
                return;
 
@@ -1161,12 +1161,12 @@ gs_shell_details_failed_response_cb (GtkDialog *dialog,
 }
 
 /**
- * gs_shell_details_filename_to_app_cb:
+ * gs_shell_details_filen_to_app_cb:
  **/
 static void
-gs_shell_details_filename_to_app_cb (GObject *source,
-                                    GAsyncResult *res,
-                                    gpointer user_data)
+gs_shell_details_file_to_app_cb (GObject *source,
+                                GAsyncResult *res,
+                                gpointer user_data)
 {
        GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source);
        GsShellDetails *self = GS_SHELL_DETAILS (user_data);
@@ -1180,9 +1180,9 @@ gs_shell_details_filename_to_app_cb (GObject *source,
        }
        /* save app */
        g_set_object (&self->app,
-                     gs_plugin_loader_filename_to_app_finish(plugin_loader,
-                                                             res,
-                                                             &error));
+                     gs_plugin_loader_file_to_app_finish (plugin_loader,
+                                                          res,
+                                                          &error));
        if (self->app == NULL) {
                GtkWidget *dialog;
 
@@ -1234,16 +1234,19 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 void
 gs_shell_details_set_filename (GsShellDetails *self, const gchar *filename)
 {
+       g_autoptr(GFile) file = NULL;
+
        gs_shell_details_set_state (self, GS_SHELL_DETAILS_STATE_LOADING);
-       gs_plugin_loader_filename_to_app_async (self->plugin_loader,
-                                               filename,
-                                               GS_PLUGIN_REFINE_FLAGS_DEFAULT |
-                                               GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
-                                               GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
-                                               GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS,
-                                               self->cancellable,
-                                               gs_shell_details_filename_to_app_cb,
-                                               self);
+       file = g_file_new_for_path (filename);
+       gs_plugin_loader_file_to_app_async (self->plugin_loader,
+                                           file,
+                                           GS_PLUGIN_REFINE_FLAGS_DEFAULT |
+                                           GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
+                                           GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
+                                           GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS,
+                                           self->cancellable,
+                                           gs_shell_details_file_to_app_cb,
+                                           self);
 }
 
 /**
@@ -173,7 +173,7 @@ gs_shell_details_switch_to (GsPage *page, gboolean scroll_up)
        gtk_widget_show (widget);
 
-       /* not set, perhaps filename-to-app */
+       /* not set, perhaps file-to-app */
        if (self->app == NULL)
                return;